import platform
import os
import subprocess
import sys
import shutil
import psutil


def get_python_version(print_flag=0):
    """
    获取 Python 版本号
    参数:
        print_flag: 是否打印信息，0 表示不打印，1 表示打印
    返回:
        str: Python 版本号字符串，例如 "3.8.5"
    """
    python_version = platform.python_version()  # 获取 Python 版本号
    if print_flag == 1:
        print(f"Python Version: {python_version}")  # 打印 Python 版本号
    return python_version


def get_installed_packages(print_flag=0):
    """
    获取已安装的 Python 库及其版本
    参数:
        print_flag: 是否打印信息，0 表示不打印，1 表示打印
    返回:
        str: 已安装库的列表字符串，格式为 "库名==版本号" 的多行字符串
            例如:
                numpy==1.19.2
                pandas==1.1.3
                ...
            如果发生错误，返回错误信息字符串
    """
    try:
        result = subprocess.run(
            [sys.executable, "-m", "pip", "list"],  # 调用 pip list 命令
            capture_output=True,  # 捕获输出
            text=True  # 输出为文本格式
        )
        installed_packages = result.stdout  # 获取输出结果
        if print_flag == 1:
            print("Installed Packages:")  # 打印标题
            print(installed_packages)  # 打印库列表
        return installed_packages
    except Exception as e:
        error_message = f"Error: {str(e)}"  # 捕获异常
        if print_flag == 1:
            print(error_message)  # 打印错误信息
        return error_message


def get_python_path(print_flag=0):
    """
    获取 Python 解释器的路径
    参数:
        print_flag: 是否打印信息，0 表示不打印，1 表示打印
    返回:
        str: Python 解释器路径字符串，例如 "/usr/bin/python3"
    """
    python_path = sys.executable  # 获取 Python 解释器路径
    if print_flag == 1:
        print(f"Python Path: {python_path}")  # 打印路径
    return python_path


def get_pip_location(print_flag=0):
    """
    获取 pip 的安装路径
    参数:
        print_flag: 是否打印信息，0 表示不打印，1 表示打印
    返回:
        str: pip 安装路径字符串，例如 "/usr/bin/pip"；
             如果 pip 未找到，返回 "pip not found"；
             如果发生错误，返回错误信息字符串
    """
    try:
        pip_path = shutil.which("pip")  # 查找 pip 路径
        if pip_path:
            if print_flag == 1:
                print(f"pip Location: {pip_path}")  # 打印 pip 路径
            return pip_path
        else:
            error_message = "pip not found"  # pip 未找到
            if print_flag == 1:
                print(error_message)  # 打印错误信息
            return error_message
    except Exception as e:
        error_message = f"Error: {str(e)}"  # 捕获异常
        if print_flag == 1:
            print(error_message)  # 打印错误信息
        return error_message


def get_os_info(print_flag=0):
    """
    获取操作系统信息
    参数:
        print_flag: 是否打印信息，0 表示不打印，1 表示打印
    返回:
        dict: 操作系统信息字典，包含以下键值对：
            - os: 操作系统类型，例如 "Windows"、"Linux" 或 "Darwin"
            - os_version: 操作系统版本，例如 "10"（对于 Windows 10）
            - windows_version: Windows 版本详细信息（仅在操作系统为 Windows 时有效），包含以下子键值对：
                - 第一个元素: Windows 产品名称，例如 "Windows 10"
                - 第二个元素: Windows 版本号，例如 "10.0.19041"
    """
    os_info = {
        "os": platform.system(),  # 操作系统类型
        "os_version": platform.release(),  # 操作系统版本
        "windows_version": platform.win32_ver() if platform.system() == "Windows" else None  # Windows 版本信息
    }
    if print_flag == 1:
        print(f"OS: {os_info['os']} {os_info['os_version']}")  # 打印操作系统信息
        if os_info['windows_version']:
            print(f"Windows Version: {os_info['windows_version'][0]} ({os_info['windows_version'][1]})")  # 打印 Windows 版本
    return os_info


def get_username(print_flag=0):
    """
    获取当前登录的用户名
    参数:
        print_flag: 是否打印信息，0 表示不打印，1 表示打印
    返回:
        str: 用户名字符串，例如 "john_doe"
    """
    try:
        username = os.getlogin()  # 获取当前登录用户名
    except Exception:
        username = os.environ.get("USER", "Unknown")  # 在某些系统上可能需要从环境变量获取
    if print_flag == 1:
        print(f"Username: {username}")  # 打印用户名
    return username


def get_cpu_info(print_flag=0):
    """
    获取 CPU 信息
    参数:
        print_flag: 是否打印信息，0 表示不打印，1 表示打印
    返回:
        dict: CPU 信息字典，包含以下键值对：
            - physical_cores: 物理核心数，例如 4
            - total_cores: 总核心数（包括逻辑核心），例如 8
            - cpu_freq: 当前 CPU 频率，单位 MHz，例如 "3599.99 MHz"
            - cpu_usage: CPU 使用率，单位 %，例如 "23.5%"
            - cpu_model: CPU 型号，例如 "Intel64 Family 6 Model 142 Stepping 10, GenuineIntel"
    """
    try:
        cpu_info = {
            "physical_cores": psutil.cpu_count(logical=False),  # 物理核心数
            "total_cores": psutil.cpu_count(logical=True),  # 总核心数（包括逻辑核心）
            "cpu_freq": f"{psutil.cpu_freq().current:.2f} MHz" if hasattr(psutil.cpu_freq(), 'current') else "N/A",  # 当前 CPU 频率
            "cpu_usage": f"{psutil.cpu_percent(interval=1)}%",  # CPU 使用率
            "cpu_model": platform.processor() or "Unknown"  # CPU 型号，某些系统可能返回空字符串
        }
        if print_flag == 1:
            print("\nCPU Information:")  # 打印标题
            print(f"  Model: {cpu_info['cpu_model']}")  # 打印 CPU 型号
            print(f"  Physical Cores: {cpu_info['physical_cores']}")  # 打印物理核心数
            print(f"  Total Cores: {cpu_info['total_cores']}")  # 打印总核心数
            print(f"  CPU Frequency: {cpu_info['cpu_freq']}")  # 打印 CPU 频率
            print(f"  CPU Usage: {cpu_info['cpu_usage']}")  # 打印 CPU 使用率
        return cpu_info
    except PermissionError:
        error_message = "Permission denied: Unable to access CPU information"
        if print_flag == 1:
            print(f"\nCPU Information:")
            print(f"  Error: {error_message}")
        return {"error": error_message}


def get_memory_info(print_flag=0):
    """
    获取内存信息
    参数:
        print_flag: 是否打印信息，0 表示不打印，1 表示打印
    返回:
        dict: 内存信息字典，包含以下键值对：
            - total: 总内存，单位 GB，例如 "15.94 GB"
            - available: 可用内存，单位 GB，例如 "11.23 GB"
            - used: 已用内存，单位 GB，例如 "4.71 GB"
            - percent: 内存使用率，单位 %，例如 "29.6%"
    """
    try:
        memory = psutil.virtual_memory()  # 获取内存信息
        memory_info = {
            "total": f"{memory.total / (1024 ** 3):.2f} GB",  # 总内存
            "available": f"{memory.available / (1024 ** 3):.2f} GB",  # 可用内存
            "used": f"{memory.used / (1024 ** 3):.2f} GB",  # 已用内存
            "percent": f"{memory.percent}%"  # 内存使用率
        }
        if print_flag == 1:
            print("\nMemory Information:")  # 打印标题
            print(f"  Total: {memory_info['total']}")  # 打印总内存
            print(f"  Available: {memory_info['available']}")  # 打印可用内存
            print(f"  Used: {memory_info['used']}")  # 打印已用内存
            print(f"  Usage: {memory_info['percent']}")  # 打印内存使用率
        return memory_info
    except PermissionError:
        error_message = "Permission denied: Unable to access memory information"
        if print_flag == 1:
            print(f"\nMemory Information:")
            print(f"  Error: {error_message}")
        return {"error": error_message}


def get_disk_partitions_info(print_flag=0):
    """
    获取硬盘各分区信息
    参数:
        print_flag: 是否打印信息，0 表示不打印，1 表示打印
    返回:
        dict: 硬盘分区信息字典，键为设备名，值为分区信息字典，包含以下键值对：
            - mount_point: 挂载点，例如 "C:\\"（Windows）或 "/home"（Linux）
            - file_system: 文件系统类型，例如 "NTFS"（Windows）或 "ext4"（Linux）
            - total: 总容量，单位 GB，例如 "232.64 GB"
            - used: 已用容量，单位 GB，例如 "120.32 GB"
            - free: 空闲容量，单位 GB，例如 "112.32 GB"
            - percent: 使用率，单位 %，例如 "51.7%"
            - error: 如果无法访问分区，返回错误信息 "Permission denied"
    """
    try:
        partitions = psutil.disk_partitions()  # 获取所有分区
        disk_info = {}  # 存储分区信息

        for partition in partitions:
            try:
                usage = psutil.disk_usage(partition.mountpoint)  # 获取分区使用情况
                disk_info[partition.device] = {
                    "mount_point": partition.mountpoint,  # 挂载点
                    "file_system": partition.fstype,  # 文件系统类型
                    "total": f"{usage.total / (1024 ** 3):.2f} GB",  # 总容量
                    "used": f"{usage.used / (1024 ** 3):.2f} GB",  # 已用容量
                    "free": f"{usage.free / (1024 ** 3):.2f} GB",  # 空闲容量
                    "percent": f"{usage.percent}%"  # 使用率
                }
                if print_flag == 1:
                    print(f"\n  Device: {partition.device}")  # 打印设备名
                    print(f"    Mount Point: {partition.mountpoint}")  # 打印挂载点
                    print(f"    File System: {partition.fstype}")  # 打印文件系统类型
                    print(f"    Total: {disk_info[partition.device]['total']}")  # 打印总容量
                    print(f"    Used: {disk_info[partition.device]['used']}")  # 打印已用容量
                    print(f"    Free: {disk_info[partition.device]['free']}")  # 打印空闲容量
                    print(f"    Usage: {disk_info[partition.device]['percent']}")  # 打印使用率
            except PermissionError:
                disk_info[partition.device] = {
                    "mount_point": partition.mountpoint,  # 挂载点
                    "file_system": partition.fstype,  # 文件系统类型
                    "error": "Permission denied"  # 错误信息
                }
                if print_flag == 1:
                    print(f"\n  Device: {partition.device}")  # 打印设备名
                    print(f"    Mount Point: {partition.mountpoint}")  # 打印挂载点
                    print(f"    File System: {partition.fstype}")  # 打印文件系统类型
                    print(f"    Error: Permission denied")  # 打印错误信息

        return disk_info
    except PermissionError:
        error_message = "Permission denied: Unable to access disk information"
        if print_flag == 1:
            print(f"\nDisk Partitions Information:")
            print(f"  Error: {error_message}")
        return {"error": error_message}


def get_system_info(
    print_python_version=0,
    print_python_path=0,
    print_pip_location=0,
    print_os_info=0,
    print_username=0,
    print_cpu_info=0,
    print_memory_info=0,
    print_disk_info=0,
    print_packages=0
):
    """
    整合所有系统信息，并允许单独控制每个项目的打印
    参数:
        print_python_version: 是否打印 Python 版本，0 表示不打印，1 表示打印
        print_python_path: 是否打印 Python 路径，0 表示不打印，1 表示打印
        print_pip_location: 是否打印 pip 路径，0 表示不打印，1 表示打印
        print_os_info: 是否打印操作系统信息，0 表示不打印，1 表示打印
        print_username: 是否打印用户名，0 表示不打印，1 表示打印
        print_cpu_info: 是否打印 CPU 信息，0 表示不打印，1 表示打印
        print_memory_info: 是否打印内存信息，0 表示不打印，1 表示打印
        print_disk_info: 是否打印硬盘分区信息，0 表示不打印，1 表示打印
        print_packages: 是否打印已安装库列表，0 表示不打印，1 表示打印
    返回:
        dict: 系统信息字典，包含以下键值对：
            - python_version: Python 版本号字符串
            - python_path: Python 解释器路径字符串
            - pip_location: pip 安装路径字符串，或错误信息
            - os_info: 操作系统信息字典
            - username: 用户名字符串
            - cpu_info: CPU 信息字典
            - memory_info: 内存信息字典
            - disk_partitions_info: 硬盘分区信息字典
            - installed_packages: 已安装库列表字符串，或错误信息
    """
    system_info = {
        "python_version": get_python_version(print_python_version),  # 获取并打印 Python 版本
        "python_path": get_python_path(print_python_path),  # 获取并打印 Python 路径
        "pip_location": get_pip_location(print_pip_location),  # 获取并打印 pip 路径
        "os_info": get_os_info(print_os_info),  # 获取并打印操作系统信息
        "username": get_username(print_username),  # 获取并打印用户名
        "cpu_info": get_cpu_info(print_cpu_info),  # 获取并打印 CPU 信息
        "memory_info": get_memory_info(print_memory_info),  # 获取并打印内存信息
        "disk_partitions_info": get_disk_partitions_info(print_disk_info),  # 获取并打印硬盘分区信息
        "installed_packages": get_installed_packages(print_packages)  # 获取并打印已安装库列表
    }
    return system_info


# 执行并获取信息
if __name__ == "__main__":
    # 示例：打印所有信息
    system_info = get_system_info(
        print_python_version=1,
        print_python_path=1,
        print_pip_location=1,
        print_os_info=1,
        print_username=1,
        print_cpu_info=1,
        print_memory_info=1,
        print_disk_info=0,
        print_packages=0
    )
    
    # 示例：仅打印 Python 版本和 CPU 信息
    # system_info = get_system_info(
    #     print_python_version=1,
    #     print_cpu_info=1
    # )


import streamlit as st
from PIL import Image # Pillow 库用于图像处理

st.title("媒体展示示例")

# 图片
st.subheader("图片展示")
# 假设你有一个名为 'example.jpg' 的图片文件
# 如果没有，你可以从网上下载一张图片并保存到你的脚本同目录下
try:
    image = Image.open('example.jpg')
    st.image(image, caption='这是一张示例图片', use_column_width=True)
except FileNotFoundError:
    st.warning("请在当前目录下放置一个 'example.jpg' 文件来查看图片示例。")
    st.image("https://www.streamlit.io/images/brand/streamlit-logo-primary-dark.png", caption="Streamlit Logo", use_column_width=True)

# 音频
st.subheader("音频播放")
audio_file = open('example.mp3', 'rb') # 假设你有一个名为 'example.mp3' 的音频文件
audio_bytes = audio_file.read()
st.audio(audio_bytes, format='audio/mp3')
audio_file.close()

# 视频
st.subheader("视频播放")
video_file = open('example.mp4', 'rb') # 假设你有一个名为 'example.mp4' 的视频文件
video_bytes = video_file.read()
st.video(video_bytes)
video_file.close()


#!/usr/bin/env python
# coding: utf-8
# 脚本起始行，指定解释器为 python 并且设置编码为 utf-8

import os  # 导入 os 模块，用于文件和目录操作
import win32com.client  # 导入 win32com.client 模块，用于与 Windows 应用程序（如 Excel）交互
import datetime  # 导入 datetime 模块，用于方便地处理日期


def convert_formula_to_value(sheet, cell_range):
    """
    将指定工作表的单元格范围内的公式转换为值。
    
    方法清单:
    - sheet.Range(cell_range): 获取指定单元格范围。
    - range_obj.Value: 获取单元格的值。
    - range_obj.Value = range_obj.Value: 将单元格值赋值给自身，去除公式。

    Args:
        sheet: Excel 工作表对象。
        cell_range: 要处理的单元格范围字符串 (例如 "B2" 或 "B5:Z100")。

    Returns:
        True 如果处理成功，False 如果处理失败。
    """
    try:
        # 获取指定的单元格范围对象
        range_obj = sheet.Range(cell_range)
        # 将范围内的值赋值给自身，从而去除公式
        range_obj.Value = range_obj.Value
        return True
    except Exception as e:
        # 捕获异常并打印错误信息
        print(f'处理工作表 "{sheet.Name}" 的范围 "{cell_range}" 时出错: {e}')
        return False


def process_excel_formulas(filepath, target_sheet_name="报告", formula_ranges=None):
    """
    去除 Excel 文件中特定单元格区域的公式，将其转换为值。

    方法清单:
    - os.path.exists(filepath): 检查文件是否存在。
    - excel_app.Workbooks.Open(filepath): 打开 Excel 文件。
    - sheet.Range(cell_range): 按范围获取单元格值。
    - workbook.Save(): 保存工作簿更改。

    Args:
        filepath: Excel 文件完整路径。
        target_sheet_name: 要处理的工作表名称，默认为 "报告"。
        formula_ranges: 包含要转换公式为值的单元格范围列表，默认为 ["B2", "B5:Z100"]。

    Returns:
        True 如果处理成功，False 如果处理失败。
    """
    if not os.path.exists(filepath):  # 检查文件是否存在
        print(f'文件不存在: {filepath}')
        return False

    excel_app = None  # 初始化 Excel 应用程序对象为 None
    workbook = None  # 初始化 Excel 工作簿对象为 None
    if formula_ranges is None:  # 如果未提供公式范围，则使用默认值
        formula_ranges = ["B2", "B5:Z100"]

    try:
        # 创建 Excel 应用程序对象
        excel_app = win32com.client.Dispatch('Excel.Application')
        # 设置 Excel 应用程序不可见
        excel_app.Visible = False
        # 打开指定的 Excel 文件
        workbook = excel_app.Workbooks.Open(filepath)
        # 禁用 Excel 的警告提示
        excel_app.DisplayAlerts = False
        # 获取指定名称的工作表
        sheet = workbook.Worksheets(target_sheet_name)

        # 遍历需要处理的单元格范围
        for cell_range in formula_ranges:
            # 调用函数将公式转化为值
            if not convert_formula_to_value(sheet, cell_range):
                return False

        # 保存工作簿
        workbook.Save()
        print(f'{workbook.Name} quCuLianJie OK')
        return True

    except Exception as e:
        # 捕获处理异常并打印详细错误信息
        print(f'处理文件 {filepath} 的公式时出错: {e}')
        return False
    finally:
        # 关闭工作簿和退出 Excel 应用程序以释放资源
        if workbook:
            workbook.Close(False)
        if excel_app:
            excel_app.Quit()


def delete_other_sheets(filepath, target_sheet_name="报告"):
    """
    删除 Excel 文件中除了指定工作表之外的所有其他工作表。

    方法清单:
    - workbook.Worksheets: 遍历所有工作表。
    - sheet.Delete(): 删除工作表。
    - workbook.Save(): 保存工作簿更改。

    Args:
        filepath: Excel 文件完整路径。
        target_sheet_name: 要保留的工作表名称，默认为 "报告"。

    Returns:
        True 如果处理成功，False 如果处理失败。
    """
    if not os.path.exists(filepath):  # 检查文件是否存在
        print(f'文件不存在: {filepath}')
        return False

    excel_app = None  # 初始化 Excel 应用程序对象为 None
    workbook = None  # 初始化 Excel 工作簿对象为 None
    try:
        # 创建 Excel 应用程序对象
        excel_app = win32com.client.Dispatch('Excel.Application')
        # 设置 Excel 应用程序不可见
        excel_app.Visible = False
        # 打开指定的 Excel 文件
        workbook = excel_app.Workbooks.Open(filepath)
        # 禁用 Excel 的警告提示
        excel_app.DisplayAlerts = False

        # 初始化一个列表，用于存储需要删除的工作表
        sheets_to_delete = []
        for sheet in workbook.Worksheets:
            # 如果工作表名称不是目标名称，则添加到删除列表
            if sheet.Name != target_sheet_name:
                sheets_to_delete.append(sheet)

        # 逆序删除，避免索引问题
        for sheet in reversed(sheets_to_delete):
            print(f'正在删除工作表: {sheet.Name}')
            sheet.Delete()

        # 保存工作簿
        workbook.Save()
        print(f'{workbook.Name} canCuSheet OK')
        return True

    except Exception as e:
        # 捕获处理异常并打印详细错误信息
        print(f'处理文件 {filepath} 的工作表时出错: {e}')
        return False
    finally:
        # 关闭工作簿和退出 Excel 应用程序以释放资源
        if workbook:
            workbook.Close(False)
        if excel_app:
            excel_app.Quit()


def find_excel_files(pathroot, file_extension=".xlsx"):
    """
    遍历指定根目录下的所有文件夹和文件，并将所有指定扩展名的文件的完整路径添加到列表中返回。

    方法清单:
    - os.walk(pathroot): 遍历目录树。
    - file.endswith(file_extension): 筛选特定扩展名文件。

    Args:
        pathroot: 根目录路径。
        file_extension: 要查找的文件扩展名，默认为 ".xlsx"。

    Returns:
        包含所有指定扩展名文件完整路径的列表。
    """
    file_list = []
    for root_dir, _, files in os.walk(pathroot):
        for file in files:
            if file.endswith(file_extension):
                file_path = os.path.join(root_dir, file)
                file_list.append(file_path)
    return file_list


def rename_excel_file(excelpath, new_file_prefix="品质检测报告"):
    """
    根据 Excel 文件的路径信息，按照特定规则重命名 Excel 文件。

    方法清单:
    - os.rename(): 重命名文件。
    - os.path.dirname(): 获取文件目录路径。
    - os.path.basename(): 获取文件名。

    Args:
        excelpath: Excel 文件完整路径。
        new_file_prefix: 新文件名的前缀，默认为 "品质检测报告"。

    Returns:
        True 如果重命名成功，False 如果重命名失败。
    """
    month_dict = {
        8: "Aug", 7: "Jul", 1: "Jan", 2: "Feb", 3: "Mar", 4: "Apr",
        5: "May", 6: "Jun", 9: "Sep", 10: "Oct", 11: "Nov", 12: "Dec"
    }

    path_parts = excelpath.split("\\")
    if len(path_parts) < 2:
        print(f'文件路径格式不正确: {excelpath}')
        return False

    folder_name = path_parts[-2]
    file_name_with_extension = path_parts[-1]

    try:
        month_year_str = folder_name
        year_str_2digit = month_year_str.split(".")[0]
        month_str_2digit = month_year_str.split(".")[1]
        month_int = int(month_str_2digit)
        month_abbr = month_dict.get(month_int)
        if not month_abbr:
            print(f'无法识别的月份: {month_str_2digit}，文件: {excelpath}')
            return False

        file_name_without_extension = file_name_with_extension.split(".")[0]
        folder_path = os.path.dirname(excelpath)

        new_file_name_without_extension = (
            f"{new_file_prefix}{file_name_without_extension}-20{year_str_2digit}-{month_abbr}"
        )
        new_file_name = new_file_name_without_extension + ".xlsx"
        new_file_path = os.path.join(folder_path, new_file_name)

        os.rename(excelpath, new_file_path)
        print(f'{new_file_path} 重命名成功。')
        return True

    except (ValueError, IndexError) as e:
        print(f'解析文件路径或文件名时出错: {e}，文件: {excelpath}')
        return False
    except FileExistsError:
        print(f'文件已存在，无法重命名: {new_file_path}')
        return False
    except Exception as e:
        print(f'重命名文件 {excelpath} 出错: {e}')
        return False


def should_rename(filepath, renamed_keyword="品质"):
    """
    检查文件是否需要重命名。如果文件名中包含指定的关键字，则认为已重命名。

    方法清单:
    - os.path.exists(filepath): 检查文件是否存在。
    - os.path.basename(): 获取文件名。

    Args:
        filepath: Excel 文件完整路径。
        renamed_keyword: 用于判断文件是否已重命名的关键字，默认为 "品质"。

    Returns:
        True 如果文件已重命名或重命名成功，False 如果文件不存在或重命名失败。
    """
    if not os.path.exists(filepath):
        print(f'文件不存在: {filepath}')
        return False

    if renamed_keyword in os.path.basename(filepath):
        print(f'{filepath} 已经完成,无需转化')
        return True
    else:
        return rename_excel_file(filepath)


def process_excel_files(root_path_list, target_filename_length=len(r"2024RD05.xlsx"),
                       target_sheet_name="报告", formula_cell_ranges=None,
                       renamed_check_keyword="品质", new_file_prefix="品质检测报告"):
    """
    遍历指定根目录列表下的所有 Excel 文件，并根据文件名进行处理。

    方法清单:
    - find_excel_files(): 查找 Excel 文件。
    - process_excel_formulas(): 转换单元格公式为值。
    - delete_other_sheets(): 删除非目标工作表。
    - should_rename(): 检查并重命名文件。

    Args:
        root_path_list: 根目录路径列表。
        target_filename_length: 需要处理的文件名的长度，默认为 len("2024RD05.xlsx")。
        target_sheet_name: 要处理的工作表名称，默认为 "报告"。
        formula_cell_ranges: 包含要转换公式为值的单元格范围列表，默认为 ["B2", "B5:Z100"]。
        renamed_check_keyword: 用于判断文件是否已重命名的关键字，默认为 "品质"。
        new_file_prefix: 新文件名的前缀，默认为 "品质检测报告"。
    """
    for root_path in root_path_list:
        print(f'正在处理目录: {root_path}')
        file_list = find_excel_files(root_path)
        if not file_list:
            print(f'目录 {root_path} 中没有找到 Excel 文件')
            continue

        for file_path in file_list:
            if len(os.path.basename(file_path)) == target_filename_length:
                print(f'处理文件: {file_path}')
                if process_excel_formulas(
                    file_path,
                    target_sheet_name=target_sheet_name,
                    formula_ranges=formula_cell_ranges
                ):
                    if delete_other_sheets(file_path, target_sheet_name=target_sheet_name):
                        should_rename(file_path, renamed_keyword=renamed_check_keyword)
                        print(f'{file_path} 处理完成')
                    else:
                        print(f'{file_path} delete_other_sheets 处理失败')
                else:
                    print(f'{file_path} process_excel_formulas 处理失败')
                print(" over")
            else:
                print(f'跳过文件: {file_path}, 文件名格式不符合条件')
        print(f'目录 {root_path} 处理完成')
    print("all over")


if __name__ == "__main__":
    root_directories = [
        r"C:\Users\frank_yu\Downloads\sc26\1348",
        r"D:\新增資料夾\中间数据"
    ]

    report_sheet = "报告"
    formula_cells = ["B2", "B5:Z100"]
    renamed_keyword_check = "品质"
    new_report_prefix = "品质检测报告"
    target_filename_len = len(r"2024RD05.xlsx")

    print("开始处理 Excel 文件...")
    process_excel_files(
        root_directories,
        target_filename_length=target_filename_len,
        target_sheet_name=report_sheet,
        formula_cell_ranges=formula_cells,
        renamed_check_keyword=renamed_keyword_check,
        new_file_prefix=new_report_prefix
    )
    print("所有 Excel 文件处理完成。")
    print("over")


import streamlit as st
import tempfile
import os
from PIL import Image  # 用于处理图片
import pandas as pd  # 用于处理 Excel

# 新增的库
import PyPDF2  # 用于处理 PDF 文件
from docx import Document  # 用于处理 Word (docx) 文件
from pptx import Presentation  # 用于处理 PowerPoint (pptx) 文件

# --- Streamlit 应用界面 ---
st.title("文件上传与处理应用")
st.write("请上传图片、音乐、视频、Excel、PDF、Word、PowerPoint 或文本文件，我会尝试处理并显示其内容。")

aaa = st.file_uploader("请选择一个文件进行上传", type=[
    "jpg", "jpeg", "png", "gif",            # 图片
    "mp3", "wav", "ogg",                    # 音乐
    "mp4", "mov", "avi",                    # 视频
    "xls", "xlsx",                          # Excel
    "pdf",                                  # PDF
    "doc", "docx",                          # Word (注意：只完全支持.docx)
    "ppt", "pptx",                          # PowerPoint (注意：只完全支持.pptx)
    "txt"                                   # 文本文件
])

if aaa:
    # 获取文件类型（MIME type）
    file_type = aaa.type
    st.info(f"检测到的文件类型: **{file_type}**")

    # --- 将上传文件保存到临时文件 ---
    # Streamlit 的 file_uploader 返回的文件对象通常在内存中，
    # 而许多处理文件的库需要实际的文件路径。
    # tempfile 模块允许安全地创建临时文件。
    
    # 获取原始文件的扩展名，用于临时文件
    file_extension = os.path.splitext(aaa.name)[1].lower() 
    
    with tempfile.NamedTemporaryFile(delete=False, suffix=file_extension) as temp_file:
        temp_file.write(aaa.read())
        temp_file_path = temp_file.name

    st.success(f"文件已临时保存到: `{temp_file_path}`")

    # --- 根据文件类型选择处理方法 ---
    # 图片文件处理
    if file_type.startswith("image/"):
        st.subheader("🖼️ 图片文件处理")
        try:
            image = Image.open(temp_file_path)
            # 使用 use_container_width 替代已弃用的 use_column_width
            st.image(image, caption=f"上传的图片: {aaa.name}", use_container_width=True) 
            st.write(f"图片尺寸: **{image.size[0]} x {image.size[1]} 像素**")
            st.write(f"图片格式: **{image.format}**")
        except Exception as e:
            st.error(f"处理图片时发生错误: {e}")

    # 音乐文件处理
    elif file_type.startswith("audio/"):
        st.subheader("🎵 音乐文件处理")
        st.audio(temp_file_path, format=file_type)
        st.info("Streamlit 内置播放器将尝试播放该音频。对于更复杂的音频处理，可能需要专门的 Python 库。")

    # 视频文件处理
    elif file_type.startswith("video/"):
        st.subheader("🎬 视频文件处理")
        st.video(temp_file_path, format=file_type)
        st.info("Streamlit 内置播放器将尝试播放该视频。对于视频分析或编辑，可能需要像 OpenCV 这样的库。")

    # Excel 文件处理
    elif file_type == "application/vnd.ms-excel" or \
         file_type == "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet":
        st.subheader("📊 Excel 文件处理")
        try:
            # 获取所有 Sheet 的名称
            xls = pd.ExcelFile(temp_file_path)
            sheet_names = xls.sheet_names
            
            st.success("Excel 文件读取成功！")
            st.write(f"该 Excel 文件包含 **{len(sheet_names)} 个 Sheet**。")
            
            # 默认显示第一个 Sheet 的前 5 行
            st.write(f"**当前显示 Sheet: `{sheet_names[0]}` (前5行)**")
            df_default = pd.read_excel(temp_file_path, sheet_name=sheet_names[0])
            st.dataframe(df_default.head()) 

            # 让用户选择查看其他 Sheet
            if len(sheet_names) > 1: # 只有当有多个 Sheet 时才显示选择器
                selected_sheet = st.selectbox("选择要查看的 Sheet:", sheet_names, index=0) # 默认选中第一个
                
                if selected_sheet:
                    st.write(f"**正在显示 Sheet: `{selected_sheet}` 的全部内容**")
                    df_selected = pd.read_excel(temp_file_path, sheet_name=selected_sheet)
                    st.dataframe(df_selected, use_container_width=True) # 显示选中 Sheet 的全部内容

            else:
                # 如果只有一个 Sheet，提供查看全部内容的选项
                with st.expander("点击查看全部内容"):
                    st.dataframe(df_default, use_container_width=True) # 显示默认 Sheet 的全部内容

        except Exception as e:
            st.error(f"处理 Excel 文件时发生错误: {e}")

    # PDF 文件处理
    elif file_type == "application/pdf":
        st.subheader("📄 PDF 文件处理")
        try:
            with open(temp_file_path, "rb") as file:
                reader = PyPDF2.PdfReader(file)
                num_pages = len(reader.pages)
                st.write(f"PDF 文件总页数: **{num_pages}**")
                
                # 尝试提取前几页的文本内容
                extracted_text = []
                for i in range(min(num_pages, 3)): # 最多提取前3页
                    page = reader.pages[i]
                    text = page.extract_text()
                    if text:
                        # 限制显示长度，避免过长的文本溢出
                        extracted_text.append(f"--- 第 {i+1} 页 ---\n{text[:500]}..." if len(text) > 500 else f"--- 第 {i+1} 页 ---\n{text}") 
                    else:
                        extracted_text.append(f"--- 第 {i+1} 页 ---\n(无法提取文本，可能为扫描件或图像PDF)")
                
                if extracted_text:
                    st.text_area("部分文本内容预览:", "\n\n".join(extracted_text), height=300)
                else:
                    st.info("无法从 PDF 中提取文本内容。")
                
        except Exception as e:
            st.error(f"处理 PDF 文件时发生错误: {e}")
            st.info("请注意，`PyPDF2` 主要用于文本 PDF，对于扫描版 PDF 可能无法提取文本。")

    # Word 文件处理 (仅支持 .docx)
    elif file_type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document": # .docx MIME type
        st.subheader("📝 Word 文件处理 (.docx)")
        try:
            document = Document(temp_file_path)
            full_text = []
            for para in document.paragraphs:
                full_text.append(para.text)
            
            doc_text = "\n".join(full_text)
            if doc_text:
                st.write(f"文档总段落数: **{len(document.paragraphs)}**")
                # 限制显示长度，避免过长的文本溢出
                st.text_area("文档内容预览 (部分):", doc_text[:1000] + "..." if len(doc_text) > 1000 else doc_text, height=300)
            else:
                st.info("无法从 Word (.docx) 文件中提取文本内容。")
        except Exception as e:
            st.error(f"处理 Word (.docx) 文件时发生错误: {e}")
            st.warning("请注意，**只完全支持 .docx 格式的 Word 文件**，不支持旧的 .doc 格式。")

    # PowerPoint 文件处理 (仅支持 .pptx)
    elif file_type == "application/vnd.openxmlformats-officedocument.presentationml.presentation": # .pptx MIME type
        st.subheader("💡 PowerPoint 文件处理 (.pptx)")
        try:
            prs = Presentation(temp_file_path)
            total_slides = len(prs.slides)
            st.write(f"演示文稿总页数: **{total_slides}**")
            
            presentation_text = []
            for i, slide in enumerate(prs.slides):
                slide_text = []
                for shape in slide.shapes:
                    if hasattr(shape, "text"):
                        slide_text.append(shape.text)
                if slide_text:
                    presentation_text.append(f"--- 第 {i+1} 页 ---\n" + "\n".join(slide_text))

            if presentation_text:
                # 限制显示前3页的内容
                st.text_area("部分演示文稿内容预览:", "\n\n".join(presentation_text[:min(total_slides, 3)]), height=300)
            else:
                st.info("无法从 PowerPoint (.pptx) 文件中提取文本内容。")

        except Exception as e:
            st.error(f"处理 PowerPoint (.pptx) 文件时发生错误: {e}")
            st.warning("请注意，**只完全支持 .pptx 格式的 PowerPoint 文件**，不支持旧的 .ppt 格式。")

    # 文本文件处理
    elif file_type.startswith("text/"): # 涵盖 text/plain, text/csv 等
        st.subheader("📜 文本文件处理")
        try:
            with open(temp_file_path, "r", encoding="utf-8") as f:
                content = f.read()
                st.write(f"文件大小: **{len(content.encode('utf-8')) / 1024:.2f} KB**")
                # 限制显示长度，避免过长的文本溢出
                st.text_area("文件内容预览:", content[:2000] + "..." if len(content) > 2000 else content, height=300)
        except UnicodeDecodeError:
            st.warning("尝试使用 `latin-1` 编码读取文本文件...")
            try:
                with open(temp_file_path, "r", encoding="latin-1") as f:
                    content = f.read()
                    st.text_area("文件内容预览:", content[:2000] + "..." if len(content) > 2000 else content, height=300)
            except Exception as e:
                st.error(f"处理文本文件时发生编码错误: {e}")
        except Exception as e:
            st.error(f"处理文本文件时发生错误: {e}")

    # 其他未支持的文件类型
    else:
        st.warning(f"🤔 抱歉，当前不支持处理类型为 `{file_type}` 的文件。")

    # --- 清理临时文件 ---
    # 确保文件处理完成后删除临时文件，避免占用磁盘空间。
    os.unlink(temp_file_path)
    st.info("临时文件已删除。")


def create_new_excel_workbook(name = r'https://d.docs.live.net/9122e41a29eea899/sb_yufengguang/xls/'):

    import datetime
    from typing import Optional, Tuple, Any
    
    
    import win32com.client
    import os
    import time
    import subprocess # 导入 subprocess 模块
    
    
    
    def process_excel_with_r1c1(
        workbook_path=None,
        sheet_name="Sheet1",
        data_to_write=[("A1", "Header"), ("B2", 100)],
        r1c1_formulas_to_set=[("C1", "=SUM(R2C2:R2C2)")],
        excel_visible=True,
        save_workbook=False,
        save_path=None,
        close_workbook=0, # 默认值改为 True 更符合清理资源的意图
        quit_excel=0,     # 默认值改为 True 更符合清理资源的意图
        kill_existing_excel=False # 新增参数，默认不终止现有进程
    ):
        """
        使用 pywin32 操作 Excel 工作簿，写入数据和设置 R1C1 样式的公式。
    
        Args:
            data_to_write (list, optional): 要写入的数据列表。每个元素是一个元组 (range_str, value)。
                                            例如：[("A1", "Header"), ("B2", 100)]。默认 None。
            r1c1_formulas_to_set (list, optional): 要设置的 R1C1 公式列表。每个元素是一个元组 (range_str, r1c1_formula_str)。
                                                  例如：[("C1", "=SUM(R1C1:R5C1)")]。默认 None。
            workbook_path (str, optional): 要打开的现有 Excel 文件路径。如果为 None，则创建一个新的工作簿。默认 None。
            sheet_name (str): 要操作的工作表名称。如果工作表不存在，此函数可能会出错（取决于 Excel COM 对象的行为）。默认 "Sheet1"。
            excel_visible (bool): 控制 Excel 应用程序是否可见。默认为 True。
            save_workbook (bool): 是否保存工作簿。默认为 False。
            save_path (str, optional): 如果 save_workbook 为 True，指定保存文件的完整路径。
                                        如果 save_workbook 为 True 但 save_path 为 None 且是新创建的工作簿，
                                        将尝试保存到当前目录下的一个临时文件名。默认 None。
            close_workbook (bool): 是否在操作完成后关闭工作簿。默认为 True。
            quit_excel (bool): 是否在操作完成后退出 Excel 应用程序。默认为 True。
            kill_existing_excel (bool): 如果为 True，则在开始处理之前强制终止所有正在运行的 EXCEL.EXE 进程。默认为 False。
    
        Returns:
            tuple: 包含 Excel 应用程序对象 (excel), 工作簿对象 (workbook), 工作表对象 (sheet)。
                   如果 quit_excel 为 True，则返回 (None, None, None)，因为对象已被释放。
                   返回这些对象是为了允许在函数外部进行更复杂的操作（如 AutoFill）。
                   如果发生错误且对象未成功创建/清理，也可能返回 None。
        """
        excel = None
        workbook = None
        sheet = None
    
        # --- 新增的逻辑：终止现有 Excel 进程 ---
        if kill_existing_excel:
            print("尝试终止现有 EXCEL.EXE 进程...")
            try:
                # 使用 taskkill 命令强制终止所有 EXCEL.EXE 进程
                # /F: Force termination
                # /IM: Image name (process name)
                # check=False: 即使没有找到进程或发生其他非致命错误，也不抛出异常
                # capture_output=True: 捕获命令的输出，避免直接打印到控制台
                result = subprocess.run(['taskkill', '/F', '/IM', 'EXCEL.EXE'], check=False, capture_output=True, text=True, encoding='gbk')
                print("Taskkill 命令执行完毕。注意：如果没有 Excel 进程运行，可能会显示错误信息，这是正常的。")
                # print(f"Taskkill stdout: {result.stdout}") # 如果需要查看 taskkill 的详细输出可以取消注释
                # print(f"Taskkill stderr: {result.stderr}")
                # 给系统一点时间来完全终止进程
                time.sleep(1)
            except FileNotFoundError:
                print("错误：找不到 taskkill 命令。请确认您是否在 Windows 系统上运行此脚本。")
            except Exception as e:
                print(f"尝试终止 Excel 进程时发生错误: {e}")
        # --- 新增逻辑结束 ---
    
        try:
            # 创建或获取 Excel 应用程序对象
            # 如果上面成功终止了现有进程，这里通常会启动一个新的 Excel 实例
            excel = win32com.client.Dispatch("Excel.Application")
            excel.Visible = excel_visible
            excel.DisplayAlerts = False
    
            # 打开现有工作簿或创建新工作簿
            if workbook_path and os.path.exists(workbook_path):
                print(f"正在打开工作簿: {workbook_path}")
                workbook = excel.Workbooks.Open(workbook_path)
                # 确保工作簿不是只读的，如果需要保存的话
                if save_workbook and workbook.ReadOnly:
                     print(f"警告: 工作簿 '{workbook_path}' 是只读的。保存可能会失败。")
                     # 可以选择另存为，或者抛出错误，这里仅警告
            else:
                if workbook_path:
                     print(f"警告: 工作簿 '{workbook_path}' 未找到。改为创建一个新的工作簿。")
                print("正在创建一个新的工作簿。")
                workbook = excel.Workbooks.Add()
    
            # 获取工作表
            try:
                sheet = workbook.Sheets(sheet_name)
                print(f"正在使用工作表: {sheet_name}")
            except Exception as e:
                print(f"获取工作表 '{sheet_name}' 时出错: {e}")
                print("回退到第一个工作表。")
                sheet = workbook.Sheets(1) # 如果指定的工作表不存在，则使用第一个工作表
    
            # 写入数据
            if data_to_write:
                print("正在写入数据...")
                for range_str, value in data_to_write:
                    try:
                        sheet.Range(range_str).Value = value
                        # print(f"写入 '{value}' 到 {range_str}")
                    except Exception as e:
                        print(f"写入 '{value}' 到范围 '{range_str}' 时出错: {e}")
    
            # 设置 R1C1 公式
            if r1c1_formulas_to_set:
                print("正在设置 R1C1 公式...")
                for range_str, r1c1_formula_str in r1c1_formulas_to_set:
                    try:
                        sheet.Range(range_str).FormulaR1C1 = r1c1_formula_str
                        # print(f"设置公式 '{r1c1_formula_str}' 到 {range_str}")
                    except Exception as e:
                         print(f"设置公式 '{r1c1_formula_str}' 到范围 '{range_str}' 时出错: {e}")
    
            # 保存工作簿
            if save_workbook:
                if save_path:
                    full_save_path = os.path.abspath(save_path) # 获取绝对路径
                elif workbook_path:
                     full_save_path = os.path.abspath(workbook_path) # 如果是打开的现有工作簿，默认保存回原路径
                else:
                    # 如果是新工作簿且没有指定保存路径，生成一个临时文件名
                    temp_dir = os.getcwd() # 保存到当前工作目录
                    temp_filename = f"temp_excel_{int(time.time())}.xlsx"
                    full_save_path = os.path.join(temp_dir, temp_filename)
                    print(f"新工作簿未指定 save_path。将保存到临时文件: {full_save_path}")
    
                try:
                    # xlWorkbookDefault = 51 (for .xlsx format)
                    # FileFormat 参数指定文件格式，避免兼容性警告
                    workbook.SaveAs(full_save_path, FileFormat=51)
                    print(f"工作簿已保存到: {full_save_path}")
                except Exception as e:
                    print(f"保存工作簿到 '{full_save_path}' 时出错: {e}")
                    # 如果保存失败，可能需要用户手动处理
    
        except Exception as e:
            print(f"在 Excel 处理过程中发生错误: {e}")
            # 发生其他未知错误
    
        finally:
            # 清理资源
            # 确保对象存在且有效，避免在出错时再次引用 None 或无效对象
            if workbook is not None:
                if close_workbook:
                    try:
                        # 根据是否需要保存来关闭工作簿
                        workbook.Close(SaveChanges=save_workbook)
                        print("工作簿已关闭。")
                    except Exception as e:
                        print(f"关闭工作簿时出错: {e}")
                # 在关闭工作簿后显式释放 COM 对象引用 (虽然 Python 的垃圾回收会处理，但显式释放有时有帮助)
                # workbook = None # 也可以考虑在这里置为 None
    
            if excel is not None:
                if quit_excel:
                    try:
                        excel.Quit()
                        print("Excel 已退出。")
                    except Exception as e:
                        print(f"退出 Excel 时出错: {e}")
                # 在退出 Excel 后显式释放 COM 对象引用
                # excel = None # 也可以考虑在这里置为 None
    
            # 返回对象，除非已退出 Excel
            # 只有在 quit_excel 为 False 且 excel 对象成功创建时才返回有效的对象
            if not quit_excel and excel is not None:
                return excel, workbook, sheet
            else:
                # 如果 Excel 已退出或未成功创建，COM 对象可能无效，返回 None
                return None, None, None
    
    
    
    
    
    
    
    
    def create_new_excel_workbook_0(
        base_name: str = "workbook_xls_",
        cloud_storage_path: str = r'https://d.docs.live.net/9122e41a29eea899/sb_yufengguang/xls/',
        local_storage_path: str = "D:\\",
        use_cloud_storage: bool = 0,
        data_to_write: Optional[list] = None,
        r1c1_formulas_to_set: Optional[list] = None,
        kill_existing_excel: bool = 0,
        quit_excel_after_creation: bool = False,
        close_workbook_after_creation: bool = False,
        save_workbook: bool = True,
        excel_visible: bool = True,
        file_extension: str = ".xlsx",
        timestamp_format: str = "%Y%m%d%H%M%S%f",
        overwrite_existing: bool = 1
    ) -> Tuple[Any, Any, Any]:
        """
        创建一个带有时间戳文件名的新Excel工作簿，并可选择写入数据和公式
        
        参数:
            base_name: 工作簿基础名称，默认为"workbook"
            cloud_storage_path: 云存储路径，默认为OneDrive路径
            local_storage_path: 本地存储路径，默认为"T:\\xls\\"
            use_cloud_storage: 是否使用云存储路径，默认为False(使用本地)
            data_to_write: 要写入的数据列表[(单元格范围, 值), ...]，默认为None
            r1c1_formulas_to_set: 要设置的R1C1公式列表[(单元格范围, 公式), ...]，默认为None
            kill_existing_excel: 是否终止现有的Excel进程，默认为True
            quit_excel_after_creation: 创建后是否退出Excel，默认为False
            close_workbook_after_creation: 创建后是否关闭工作簿，默认为False
            save_workbook: 是否保存工作簿，默认为True
            excel_visible: Excel是否可见，默认为True
            file_extension: 文件扩展名，默认为".xlsx"
            timestamp_format: 时间戳格式，默认为"%Y%m%d%H%M%S%f"
            overwrite_existing: 如果文件存在是否覆盖，默认为False
            
        返回:
            元组: (Excel应用对象, 工作簿对象, 工作表对象) 如果已退出则返回(None, None, None)
        """
        try:
            # 生成时间戳
            timestamp = datetime.datetime.now().strftime(timestamp_format)
            
            # 确定存储路径
            storage_path = cloud_storage_path if use_cloud_storage else local_storage_path
            
            # 创建完整文件路径
            filename = f"{base_name}_{timestamp}{file_extension}"
            full_path = storage_path + filename
            
            print(f"正在创建新工作簿: {full_path}")
            
            # 检查文件是否存在(如果不允许覆盖)
            if not overwrite_existing and os.path.exists(full_path):
                raise FileExistsError(f"文件已存在: {full_path}")
            
            # 创建工作簿
            excel_app, workbook, worksheet = process_excel_with_r1c1(
                kill_existing_excel=kill_existing_excel,
                data_to_write=data_to_write,
                quit_excel=quit_excel_after_creation,
                r1c1_formulas_to_set=r1c1_formulas_to_set,
                close_workbook=close_workbook_after_creation,
                save_path=full_path,
                save_workbook=save_workbook,
                excel_visible=excel_visible
            )
            
            return excel_app, workbook, worksheet
            
        except FileExistsError as fee:
            print(f"错误: {fee}")
            return None, None, None
        except Exception as e:
            print(f"创建工作簿时发生意外错误: {e}")
            return None, None, None
    
    
    
    app,book,sh= create_new_excel_workbook_0()
    
    book.Name
    
    book.SaveAs(name+book.Name)
    print(f"创建工作簿: {name+book.Name}")
    
    return app,book,sh


aaa = r'''
于风广，自动共享
风广同事，自动添加，2023M12
于琳祥共享
yurx2017
于荣祥yufg2023，自动共享
荣祥自动共享202307
父母兄弟
dengchunying1988,人物，添加时间，2024m01

风广同学，自动添加，2023M12

于书亚，自动共享

邓春英，自动共享



Dcy1988
Yeah,人物

Yufg202003人物照
yufengguang,人物照

qingfeng.weichen人物照

邓春英2007,qingfeng
Y2023人物头像
一家人

于风广
邓春英头像
邓春英
人物清单202503非常重要
202503人物
动物园20250212
视频202408-t102
sc210002，202408
书亚，kelly的诗人相册
视频精选202408
单曲循环202408
相冊路徑 yufg202408 https://photos.app.goo.gl/xFq459pxyrwbLzac9
书亚恐龙宝宝
非常重要，2024M05.kelly
书亚共享，yufg202408
荣祥共享，yufg202408
我的家庭yufg202408
sb-yufg202408

sa-yufg202408

sa02

武梅兰，yeah

武梅兰
于琳萱

Y2023视频

yufengguang,g,視頻
yufg202403,人物,增加時間
非常重要

于琳萱
Y2024M03
于书亚
Y2023M07共享
yufg202403,g,視頻,拍攝時間
yufg202402gmailcom,所有照片

Dengchunying1988,人物，拍摄时间

Y2023M09
非常重要，2024M02，dengchunying

Y2024M01，yufengguang

蒋静，qingfeng
证件
Y2023M10,dcy
Y2023M11, yufg87
時間不對2023M11
于风广，自动共享
yeah，人物照
红飘毕业

于书亚yufg2023
岑文姬
西平时光
于琳祥yufeng

Y2023大杂烩
韶关时光
聂细端
圣心一日游
广州烈士陵园
半日游
favor
anglelina
小照片
照片投放箱
白云山高





'''



bbb = r'''
https://photos.app.goo.gl/pvdeUCwV5KoCot3q7
https://photos.app.goo.gl/Tg5k6t5TsAv8b8GU6
https://photos.app.goo.gl/m7gqwxq9vNnRenEr6
https://photos.app.goo.gl/nxv6dzFNxn48vQc37

https://photos.app.goo.gl/wofTvH5md17vfvhA8

https://photos.app.goo.gl/G3UUuxjTC6tTVWYS6
https://photos.app.goo.gl/MCqz6j6ucyjQLyv68
https://photos.app.goo.gl/umTyc3qv7CP9xbvc8

https://photos.app.goo.gl/dMnTWEmGaHSC6uMK7

https://photos.app.goo.gl/nzvTyzyaPoY9iPW47

https://photos.app.goo.gl/z5GhHem2UfLQrug2A


https://photos.app.goo.gl/ccWwJZntRhZj1fDC8

https://photos.app.goo.gl/SfNP24AQkVQsxh6j6

https://photos.app.goo.gl/z6hnSrQu2TD4CZ8j7

https://photos.app.goo.gl/kBE3a9AxNvATFrCW6

https://photos.app.goo.gl/C31RUK4eSDwtJ9Fi6

https://photos.app.goo.gl/m6V8F4xsjFYTBVVJA


https://photos.app.goo.gl/orT91TxcZ94g28Qt5
https://photos.app.goo.gl/wLTLLgNkMqxqCZBT6

https://photos.app.goo.gl/ywLPXmvRQNA36XhdA

https://photos.app.goo.gl/bxFwnEYt7Ce4BgXTA

https://photos.app.goo.gl/QxMnh3cuCgtxK97R8
https://photos.app.goo.gl/fnMQiXeZnG4jst6N7

https://photos.app.goo.gl/H7UCSywzoK6LmjQK9
https://photos.app.goo.gl/teQxx1sNMkKW2VME8
https://photos.app.goo.gl/hGK1w4wVVpFAQdN47
https://photos.app.goo.gl/HAL16dnmNT2nhnwP7

https://photos.app.goo.gl/NY8oaMR4qWgBJXHc9

https://photos.app.goo.gl/WLaUPy56VBL3ZP6B8

https://photos.app.goo.gl/d98uCjfqf8vkxQDo9
https://photos.app.goo.gl/xFq459pxyrwbLzac9

https://photos.app.goo.gl/3H3vQsS8o23Pzewm6
https://photos.app.goo.gl/nb46uAzoG2cN5vy69

https://photos.app.goo.gl/BP7wLRdNgmJ3QUDE6
https://photos.app.goo.gl/AuFigdqcyh6wD1BB6

https://photos.app.goo.gl/TtPa7B86HGruA1kV7

https://photos.app.goo.gl/uf26AGeast8M9JJy8

https://photos.app.goo.gl/442ByPxRfJN7e14g7

https://photos.app.goo.gl/hea8JJjR9PonN3iU9

https://photos.app.goo.gl/zDVxKk3Sn2oaLjea7

https://photos.app.goo.gl/fSXm47NTJBSVcCLw7

https://photos.app.goo.gl/NmehE4xwAB2T7QDg9

https://photos.app.goo.gl/ByYPeQ6Q4EoKbmudA

https://photos.app.goo.gl/AzZnUv9HbJyVKKNx5

https://photos.app.goo.gl/ZpqLHcEtAgDaEVw37

https://photos.app.goo.gl/Hn2kbTFPVncvTg8t7
https://photos.app.goo.gl/EWZyRWosLZfkSQJG7
https://photos.app.goo.gl/FYH4yph4Kado2dEC7
https://photos.app.goo.gl/9XmXrdmTMPo68x9i8
https://photos.app.goo.gl/hEQ7oQgahwCNf1Sh9
https://photos.app.goo.gl/mVrdRW3pRm84CFHy6

https://photos.app.goo.gl/eizGfEcJ4zduAbwZ8
https://photos.app.goo.gl/dQMoK1ZY2Fud7FXPA
https://photos.app.goo.gl/NLkZirCH4yYVDKK86
https://photos.app.goo.gl/NrSEqRPKAVGE4vgJA
https://photos.app.goo.gl/3aAGJs92mbBDbNe89

https://photos.app.goo.gl/ncfTjCMiX7Uzy445A

https://photos.app.goo.gl/4CXZrb4v3g2o6jJ96
https://photos.app.goo.gl/U67zL8LajyxNaq5M8

https://photos.app.goo.gl/ZnHnFjYmcEMP6GgEA

https://photos.app.goo.gl/d1V1Jn6mGeDMfxLq9

https://photos.app.goo.gl/pvdeUCwV5KoCot3q7
https://photos.app.goo.gl/56Vcu2VYJ1eoZjYL6

https://photos.app.goo.gl/pDUYHHgf9mEjbzAm6

https://photos.app.goo.gl/tXs146BBhcC829Uo8


https://photos.app.goo.gl/NsHLv9xP5UPqchsp9
https://photos.app.goo.gl/aWLeBAGCMzuFCjPQ6
https://photos.app.goo.gl/eeDQao7W8roxnz3N6
https://photos.app.goo.gl/q6Fdbg5XPqZWZzJe9

https://photos.app.goo.gl/KBuUqaH6aWXr4t9RA

https://photos.app.goo.gl/ndgU7ee1AAfVLMAo8

https://photos.app.goo.gl/qrRyNA9xwK7VbmGh6
https://photos.app.goo.gl/iW7uG7BqsRjxgPRw9
https://photos.app.goo.gl/djHmatT3AwCvXiy26
https://photos.app.goo.gl/V5HXS8ZXyQPjb6u86
https://photos.app.goo.gl/doaPy1Q8vamiH9XEA
https://photos.app.goo.gl/7dwJ9Zqam16jj4JRA
https://photos.app.goo.gl/vJuA7dnF6d28HUJa8
https://photos.app.goo.gl/GgJT86hDJufCuCSe8


'''


#!/usr/bin/env python
# coding: utf-8

# In[7]:


"""Windows.edb是Windows Search索引文件，主要用于提供内容索引、属性缓存以及文件、电子邮件和其他内容的搜索结果。由于Windows系统默认会对文件进行索引以加快搜索速度，所有与索引有关的数据都存储在这个edb文件中。随着使用时间的增长，Windows.edb文件可能会变得非常大，占用大量磁盘空间‌
1
2
。

删除Windows.edb文件的步骤
‌停止Windows Search服务‌：
打开“命令提示符”（以管理员身份运行）。
输入以下命令来停止Windows Search服务：net stop wsearch。
输入以下命令来禁用Windows Search服务的自动启动：sc config wsearch start= disabled。
‌删除Windows.edb文件‌：
导航到文件路径：C:\ProgramData\Microsoft\Search\Data\Applications\Windows。
删除Windows.edb文件。
‌重新启动Windows Search服务‌：
输入以下命令来启动Windows Search服务：net start wsearch。
输入以下命令来恢复Windows Search服务的自动启动：sc config wsearch start= delayed-auto‌
1
2
。
删除后是否会重新生成
删除Windows.edb文件后，只要Windows Search服务继续运行，该文件会重新生成。因此，如果希望彻底删除该文件并阻止其重新生成，需要停止使用Windows Search服务或完全禁用该服务‌
3
。
"""


# In[2]:


aaa = "net stop wsearch"


# In[1]:


bbb = r"sc config wsearch start= disabled"


# In[4]:


ccc = r"net start wsearch"


# In[5]:


eee = "sc config wsearch start= delayed-auto"


# In[10]:


for i in [aaa,bbb]:
    import os
    import time
    
    os.system(i)
    time.sleep(10)


# In[11]:


for i in [ccc,ddd]:
    import os
    import time
    
    os.system(i)
    time.sleep(10)


# In[ ]:







import frankyu.xlsx.active_excel_objects_get_2 as ac

def url(file_path: str=r'https://d.docs.live.net/380c326fa2fd9c70/%E7%A7%81%E4%BA%BA%E6%96%87%E4%BB%B6%EF%BC%8Cdengchunying1988/%E6%A1%8C%E9%9D%A2%201/%E5%AD%A6%E4%B9%A0/%E5%AE%B6%E5%BA%AD%E8%B4%A6%E7%B0%BF%E6%9B%B4%E6%96%B0%E4%BA%8E2025%E5%B9%B43%E6%9C%8812%E6%97%A5.xlsx'
, file_name: str='家庭账簿更新于2025年3月12日.xlsx'):
    """
    Opens an Excel workbook. If the workbook is already open, it prints a message.
    Otherwise, it opens the workbook from the given path.

    Args:
        file_path (str): The full path to the Excel file.
        file_name (str): The name of the Excel file (e.g., "my_workbook.xlsx").
    """
    app, b, c, d = ac.active_excel_objects_get()

    workbook_found = False
    for workbook in app.Workbooks:
        if workbook.Name == file_name:
            print(f"'{file_name}' 已经打开")
            workbook_found = True
            break

    if not workbook_found:
        app.Workbooks.Open(file_path)
        print(f"'{file_name}' 已经打开") # Added this line for clarity after opening

if __name__ == "__main__":
    url()


import win32com.client
import pythoncom
import sys
import traceback

# Excel 常數 (對應到 VBA 常數)
xlContinuous = 1
xlThin = 2
xlExpression = 1
xlLeft = 1
xlRight = 2
xlTop = 3
xlBottom = 4
xlThemeColorDark1 = 1


def apply_font_conditional_formatting(sheet,target_range_str="A1:AA999", formula="=OR(A1=\"\",A1=0)"):
    """
    為指定的範圍加入條件式格式設定，並應用字體顏色。
    """
    target_range = sheet.Range(target_range_str)
    try:
        from win32com.client import constants
        if target_range.MergeCells:
            print("目標範圍包含合併儲存格，請確認並重試。")
            return

        format_condition = target_range.FormatConditions.Add(Type=constants.xlExpression, Formula1=formula)
        format_condition.SetFirstPriority()
        print(f"已加入條件式格式設定規則 (字體顏色)，公式: {formula}。")

        font = format_condition.Font
        font.ThemeColor = xlThemeColorDark1
        print("已為條件式格式設定規則應用字體顏色。")
    except Exception as e:
        print(f"應用字體顏色條件式格式設定時發生錯誤: {e}")
        traceback.print_exc()


